=========
RECLUSE
=========

Release 0.1.6 (2013-09-15)
..........................
* Fixed packaging error in which the package was named 'code' instead of 'recluse'.


Release 0.1.5 (2013-09-15)
..........................
* Added vocabulary building tools: vocabulary_cutter and vocabulary_generator.

Release 0.1.4 (2013-09-14)
..........................
* Little typographical fixes.

Release 0.1.3 (2013-09-14)
..........................
* Little typographical fixes.

Release 0.1.2 (2013-09-14)
..........................
* Added the nltk_based_segmenter_tokeniser.


Release 0.1.1 (2013-09-10)
..........................
* Added a test of the commandline functionality of article_randomizer.
* Added utils.py with the open_with_unicode function.


Release 0.1.0 (2013-09-05)
..........................
Initial release.
